Struct Worker
struct Worker<T> { ... }
A worker queue.
This is a FIFO or LIFO queue that is owned by a single thread, but other threads may steal tasks from it. Task schedulers typically create a single worker queue per thread.
Examples
A FIFO worker:
use ;
let w = new_fifo;
let s = w.stealer;
w.push;
w.push;
w.push;
assert_eq!;
assert_eq!;
assert_eq!;
A LIFO worker:
use ;
let w = new_lifo;
let s = w.stealer;
w.push;
w.push;
w.push;
assert_eq!;
assert_eq!;
assert_eq!;
Implementations
impl<T> Worker<T>
fn new_fifo() -> Worker<T>Creates a FIFO worker queue.
Tasks are pushed and popped from opposite ends.
Examples
use Worker; let w = new_fifo;fn new_lifo() -> Worker<T>Creates a LIFO worker queue.
Tasks are pushed and popped from the same end.
Examples
use Worker; let w = new_lifo;fn stealer(self: &Self) -> Stealer<T>Creates a stealer for this queue.
The returned stealer can be shared among threads and cloned.
Examples
use Worker; let w = new_lifo; let s = w.stealer;fn is_empty(self: &Self) -> boolReturns
trueif the queue is empty.use Worker; let w = new_lifo; assert!; w.push; assert!;fn len(self: &Self) -> usizeReturns the number of tasks in the deque.
use Worker; let w = new_lifo; assert_eq!; w.push; assert_eq!; w.push; assert_eq!;fn push(self: &Self, task: T)Pushes a task into the queue.
Examples
use Worker; let w = new_lifo; w.push; w.push;fn pop(self: &Self) -> Option<T>Pops a task from the queue.
Examples
use Worker; let w = new_fifo; w.push; w.push; assert_eq!; assert_eq!; assert_eq!;
impl<T> Any for Worker<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Worker<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Worker<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Debug for Worker<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Freeze for Worker<T>
impl<T> From for Worker<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Pointable for Worker<T>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> RefUnwindSafe for Worker<T>
impl<T> Sync for Worker<T>
impl<T> Unpin for Worker<T>
impl<T> UnsafeUnpin for Worker<T>
impl<T> UnwindSafe for Worker<T>
impl<T, U> Into for Worker<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Worker<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Worker<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>